@@ -8,7 +8,14 @@ from celery import Celery
 from django.conf import settings
 
 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.settings')
-os.environ.setdefault('DJANGO_CONFIGURATION', 'Development')
+
+from dotenv import load_dotenv
+# explicitly providing path to '.env'
+from pathlib import Path  # python3 only
+env_path = Path('.') / '.crm'
+load_dotenv(dotenv_path=env_path)
+
+os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION'))
 
 
 # os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.dev_settings')
